export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
for schema in apps_evolution_addressbook-1.5 apps_evolution_calendar-1.5 \
evolution-mail-1.5 apps_evolution_shell-1.5 ; do
  gconftool-2 --makefile-install-rule etc/gconf/schemas/$schema.schemas 1>/dev/null 2>/dev/null
done

if [ -x /usr/bin/scrollkeeper-update ]; then
  /usr/bin/scrollkeeper-update -p /var/lib/scrollkeeper 1>/dev/null 2>/dev/null
fi
( cd usr/lib/evolution/1.5 ; rm -rf libeutil.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libeutil.so.0.0.0 libeutil.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libeutil.so )
( cd usr/lib/evolution/1.5 ; ln -sf libeutil.so.0.0.0 libeutil.so )
( cd usr/lib/evolution/1.5 ; rm -rf libeconduit.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libeconduit.so.0.0.0 libeconduit.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libeconduit.so )
( cd usr/lib/evolution/1.5 ; ln -sf libeconduit.so.0.0.0 libeconduit.so )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-a11y.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-a11y.so.0.0.0 libevolution-a11y.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-a11y.so )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-a11y.so.0.0.0 libevolution-a11y.so )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-calendar-a11y.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-calendar-a11y.so.0.0.0 libevolution-calendar-a11y.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-calendar-a11y.so )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-calendar-a11y.so.0.0.0 libevolution-calendar-a11y.so )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-widgets-a11y.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-widgets-a11y.so.0.0.0 libevolution-widgets-a11y.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-widgets-a11y.so )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-widgets-a11y.so.0.0.0 libevolution-widgets-a11y.so )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-addressbook-a11y.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-addressbook-a11y.so.0.0.0 libevolution-addressbook-a11y.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-addressbook-a11y.so )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-addressbook-a11y.so.0.0.0 libevolution-addressbook-a11y.so )
( cd usr/lib/evolution/1.5 ; rm -rf libemiscwidgets.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libemiscwidgets.so.0.0.0 libemiscwidgets.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libemiscwidgets.so )
( cd usr/lib/evolution/1.5 ; ln -sf libemiscwidgets.so.0.0.0 libemiscwidgets.so )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-importer.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-importer.so.0.0.0 libevolution-importer.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-importer.so )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-importer.so.0.0.0 libevolution-importer.so )
( cd usr/lib/evolution/1.5 ; rm -rf libeshell.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libeshell.so.0.0.0 libeshell.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libeshell.so )
( cd usr/lib/evolution/1.5 ; ln -sf libeshell.so.0.0.0 libeshell.so )
( cd usr/lib/evolution/1.5 ; rm -rf libcamel.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libcamel.so.0.0.0 libcamel.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libcamel.so )
( cd usr/lib/evolution/1.5 ; ln -sf libcamel.so.0.0.0 libcamel.so )
( cd usr/lib/evolution/1.5 ; rm -rf libeselectnames.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libeselectnames.so.0.0.0 libeselectnames.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libeselectnames.so )
( cd usr/lib/evolution/1.5 ; ln -sf libeselectnames.so.0.0.0 libeselectnames.so )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-mail-importers.so.0 )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-mail-importers.so.0.0.0 libevolution-mail-importers.so.0 )
( cd usr/lib/evolution/1.5 ; rm -rf libevolution-mail-importers.so )
( cd usr/lib/evolution/1.5 ; ln -sf libevolution-mail-importers.so.0.0.0 libevolution-mail-importers.so )
