/* -*- Mode: IDL; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Common definitions for the CORBA interface for the Evolution shell.
 *
 * Authors:
 *   Ettore Perazzoli <ettore@ximian.com>
 *
 * Copyright (C) 2000, 2001, 2002 Ximian, Inc.
 */

module GNOME {
module Evolution {
	struct Icon {
		short width, height;
		boolean hasAlpha;
		sequence <octet> rgbaData; // Row-by-row, left-to-right, top-to-bottom RGBA bytes
	};

	typedef sequence <Icon> AnimatedIcon;

};
};

