/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
/* e-shell-corba-icon-utils.h
 *
 * Copyright (C) 2002  Ximian, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author: Ettore Perazzoli
 */

#ifndef E_SHELL_ICON_UTILS_H
#define E_SHELL_ICON_UTILS_H

#include "Evolution.h"

#include <gdk-pixbuf/gdk-pixbuf.h>


void                          e_store_corba_icon_from_pixbuf               (GdkPixbuf             *pixbuf,
									    GNOME_Evolution_Icon  *icon_return);
GNOME_Evolution_Icon         *e_new_corba_icon_from_pixbuf                 (GdkPixbuf             *pixbuf);
GNOME_Evolution_AnimatedIcon *e_new_corba_animated_icon_from_pixbuf_array  (GdkPixbuf            **pixbuf_array);

GdkPixbuf *e_new_gdk_pixbuf_from_corba_icon  (const GNOME_Evolution_Icon *icon,
					      int                         scaled_width,
					      int                         scaled_height);

#endif
