/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * CORBA interface for the SelectNames dialog.
 *
 * Authors:
 *   Ettore Perazzoli <ettore@ximian.com>
 *
 * Copyright (C) 2000 Ximian, Inc.
 */

#include <Bonobo.idl>

module GNOME {
module Evolution {
module Addressbook {

	interface SelectNames : Bonobo::Unknown {
		struct Section {
			string id;
			string title;
		};

		typedef sequence<Section> SectionList;

		exception DuplicateID {};
		exception SectionNotFound {};

		void addSection (in string id, in string title)
			raises (DuplicateID);
		void addSectionWithLimit (in string id, in string title, in short limit)
			raises (DuplicateID);

		Bonobo::Control getEntryBySection (in string section_id)
			raises (SectionNotFound);

		void activateDialog (in string section_id);
	};


};
};
};
